#!/bin/sh
# Updated : October 22, 2019
# Author  : Romnick C. Coros

. /tmp/openit-cfg-shenv

LIBEXEC="$ROOT_DIR/libexec"
HTTPDCONF="$CONFIG_DIR/httpd/httpd.conf"
PHPINI="/etc/opt/openit/php.ini"
FOLDER=""
ver=""

# Get OS version. Make sure we don't copy binaries and PHP files on RHEL/CentOS 5
releases=( /etc/*release )
OSVERSION=`cat ${releases[0]} | grep -oP '(?<=release )[0-9]+'`

#Get the first two part of the version
if [ -e $CONFIG_DIR/version ]; then
        ver=`cat $CONFIG_DIR/version | cut -d "." -f 1-2 | tr -d '.'`
else
        ver=`grep VERSION $ROOT_TEMP_DIR/inst/package/accserver.info | cut -d" " -f2 | cut -d "." -f 1-2 | tr -d '.'`
fi

#Check which architecture we have
if [ `uname` = "Linux" ]; then
	#Copy the new php binary
	if [ `uname -p` = "i686" ]; then
		FOLDER="i686-redhat-linux"
	else
		FOLDER="x86_64-unknown-linux"
	fi
fi

# on RHEL 6 and up copy files for PHP 7.0.33 and Apache build on CentOS 6
if [ $OSVERSION -ne 5 ]; then
    #Copy the new binary to the installation
    cp files/bin/$FOLDER/php "$LIBEXEC/$FOLDER/bin/php"
    cp files/bin/$FOLDER/httpd "$LIBEXEC/$FOLDER/bin/httpd"
else
    #Copy the new binary to the installation
    cp files/bin/$FOLDER/php_centos5 "$LIBEXEC/$FOLDER/bin/php"
    cp files/bin/$FOLDER/httpd_centos5 "$LIBEXEC/$FOLDER/bin/httpd"

    #Copy the new library to the installation
    cp files/lib/$FOLDER/ixed.7.1.lin "$LIBEXEC/$FOLDER/lib/ixed.7.1.lin"

    #Replace ixed.7.0.lin with ixed.7.1.lin
	sed -i -e '/extension=/d' $PHPINI
	echo  'extension=/opt/openit/libexec/x86_64-unknown-linux/lib/ixed.7.1.lin' >> $PHPINI
fi

# Update openit.cfg for automatic removal of old clients from the dashboard #RM 12489s
OPENITCFG="/etc/opt/openit/openit.cfg"
PATTERN='CLIENT_INFO_MAX_DAYS'
if grep -q -F $PATTERN $OPENITCFG; then
	sed -i -e '/CLIENT_INFO_MAX_DAYS \+0/d'  $OPENITCFG
	if grep -q -F $PATTERN $OPENITCFG; then
		echo "Found CLIENT_INFO_MAX_DAYS with custom data no need to insert."	
	else
		echo -e  '\nCLIENT_INFO_MAX_DAYS    0' >> $OPENITCFG
	fi
else
	echo -e  '\nCLIENT_INFO_MAX_DAYS    0' >> $OPENITCFG
fi

#Remove the Security Headers if already existing
sed -i -e '/X-XSS-Protection/d' $HTTPDCONF
sed -i -e '/Content-Security-Policy/d' $HTTPDCONF
sed -i -e '/X-Content-Type-Options/d' $HTTPDCONF
sed -i -e '/Strict-Transport-Security/d' $HTTPDCONF
sed -i -e '/Referrer-Policy/d' $HTTPDCONF
sed -i -e '/Feature-Policy/d' $HTTPDCONF
sed -i -e '/Header always append X-Frame-Options SAMEORIGIN/d' $HTTPDCONF

#Add Security Headers
sed -i -e '/<IfModule headers_module>/ a\
    Header set X-XSS-Protection \"1; mode=block\"' $HTTPDCONF
sed -i -e '/Header set X-XSS-Protection/ a\
    Header set Content-Security-Policy: \"frame-ancestors 'self'\"' $HTTPDCONF
sed -i -e '/Content-Security-Policy/ a\
    Header set X-Content-Type-Options "nosniff"' $HTTPDCONF
sed -i -e '/X-Content-Type-Options/ a\
    Header always set Strict-Transport-Security: "max-age=31536000; includeSubDomains"' $HTTPDCONF
sed -i -e '/Strict-Transport-Security/ a\
    Header always set Referrer-Policy: strict-origin-when-cross-origin' $HTTPDCONF
sed -i -e '/Referrer-Policy/ a\
    Header always set Feature-Policy \"geolocation '"'"'none'"'"'; midi '"'"'none'"'"'; camera '"'"'none'"'"'; usb '"'"'none'"'"'; magnetometer '"'"'none'"'"'; accelerometer '"'"'none'"'"'; vr '"'"'none'"'"'; speaker '"'"'none'"'"'; ambient-light-sensor '"'"'none'"'"'; gyroscope '"'"'none'"'"'; microphone '"'"'none'"'"'; payment '"'"'none'"'"'; fullscreen '"'"'self'"'"'\"' $HTTPDCONF
sed -i -e '/Feature-Policy/ a\
    Header always append X-Frame-Options SAMEORIGIN' $HTTPDCONF

